@@ -2,6 +2,8 @@ import numpy as np
 import pandas as pd
 import sys
 
+from sklearn.preprocessing import KBinsDiscretizer
+
 class _BasicDataGenerator():
     def __init__(self):
         self.n_rows = None
@@ -31,13 +33,12 @@ class MatrixGenerator(_BasicDataGenerator):
         noise = np.random.normal(loc = loc, scale = noise_sigmas, size = (self.n_rows,self.n_cols))
         return noise
 
-    def generate(self,n_rows = 100, n_basic_cols = 10, loc = 0,  noise_sigmas = None, basic_cost = 1, seed = None, round_level = None):
+    def generate(self,n_rows = 100, n_basic_cols = 10, loc = 0,  noise_sigmas = None, basic_cost = 1, seed = None, discretize_method = 'uniform', discretize_bins=10):
         assert isinstance(n_rows, int), "Argument `n_rows` must be int."
         assert isinstance(n_basic_cols, int), "Argument `n_cols` must be int."
         assert isinstance(loc, int), "Argument `loc` must be int or float."
-        # assert (isinstance(noise_sigmas, list)) or noise_sigmas is None, "Argument `noise_sigmas` must be list of floats from range (0,1]."
-        # if noise_sigmas is not None:
-        #     assert ((min(noise_sigmas) > 0) and (max(noise_sigmas) <= 1)), "Argument `noise_sigmas` must be list of floats from range (0,1]."
+        assert discretize_method in ['uniform', 'quantile', 'kmeans'], "Argument `discretize_method` must be in ['uniform', 'quantile', 'kmeans']"
+        assert discretize_bins > 1 and isinstance(discretize_bins, int), "Argument `discretize_bins` must be int greater then 1."
         
 
         super().generate(n_rows, n_basic_cols, seed)
@@ -59,9 +60,13 @@ class MatrixGenerator(_BasicDataGenerator):
             X = np.concatenate((X,X_transformed), axis=1)
             costs = costs + [1/(noise_sigma + basic_cost) for i in range(self.n_cols)]
 
-        # Round output if selected
-        if round_level:
-            X = X.round(round_level)
+        # Discretize data
+        def discretize(vector, **kwargs):
+            discretizer = KBinsDiscretizer(encode='ordinal', **kwargs)
+            vector = discretizer.fit_transform(vector.reshape(-1,1)).reshape(-1)
+            return vector
+        
+        X = np.apply_along_axis(func1d=discretize, axis=0, arr=X, n_bins=discretize_bins, strategy=discretize_method)
         
         return X, y, costs
 
@@ -73,8 +78,8 @@ class DataFrameGenerator(MatrixGenerator):
         new_cols = ['var_' + str(i) for i in np.arange(1,n+1)]
         return new_cols
 
-    def generate(self,n_rows = 100, n_basic_cols = 10, loc = 0,  noise_sigmas = None, seed = None, round_level = None):
-        X,y,costs = super().generate(n_rows = n_rows, n_basic_cols = n_basic_cols, loc = loc,  noise_sigmas = noise_sigmas, seed = seed, round_level = round_level)
+    def generate(self,n_rows = 100, n_basic_cols = 10, loc = 0,  noise_sigmas = None, seed = None, discretize_method = 'uniform', discretize_bins=10):
+        X,y,costs = super().generate(n_rows = n_rows, n_basic_cols = n_basic_cols, loc = loc,  noise_sigmas = noise_sigmas, seed = seed, discretize_method = discretize_method, discretize_bins=discretize_bins)
         # Generate colnames
         if noise_sigmas is None:
             noise_sigmas_len = 0
