@@ -74,10 +74,10 @@ def mifs(data, target_variable, prev_variables_index, candidate_variable_index,
     assert isinstance(beta,int) or isinstance(beta,float), "Argument 'beta' must be int or float"
 
     candidate_variable = data[:,candidate_variable_index]
-    
-    redundancy_sum = 0
-    for var in prev_variables_index:
-        redundancy_sum += mutual_information(data[:,var], candidate_variable)
+    if len(prev_variables_index) == 0:
+        redundancy_sum = 0
+    else:
+        redundancy_sum = np.apply_along_axis(mutual_information, axis = 0, arr = data[:,prev_variables_index], vector_2=candidate_variable).sum()
     
     return mutual_information(candidate_variable, target_variable) - beta*redundancy_sum
 
@@ -116,9 +116,10 @@ def mrmr(data, target_variable, prev_variables_index, candidate_variable_index,
     candidate_variable = data[:,candidate_variable_index]
     prev_variables_len = 1 if len(prev_variables_index) == 0 else len(prev_variables_index)
     
-    redundancy_sum = 0
-    for var in prev_variables_index:
-        redundancy_sum += mutual_information(data[:,var], candidate_variable)
+    if len(prev_variables_index) == 0:
+        redundancy_sum = 0
+    else:
+        redundancy_sum = np.apply_along_axis(mutual_information, axis = 0, arr = data[:,prev_variables_index], vector_2=candidate_variable).sum()
     
     return mutual_information(candidate_variable, target_variable) - 1/prev_variables_len*redundancy_sum
 
@@ -157,12 +158,12 @@ def jmi(data, target_variable, prev_variables_index, candidate_variable_index, *
     candidate_variable = data[:,candidate_variable_index]
     prev_variables_len = 1 if len(prev_variables_index) == 0 else len(prev_variables_index)
 
-    redundancy_sum = 0
-    for var in prev_variables_index:
-        
-        a = mutual_information(data[:,var], candidate_variable)
-        b = conditional_mutual_information(data[:,var], candidate_variable, target_variable)
-        redundancy_sum += a - b
+    if len(prev_variables_index) == 0:
+        redundancy_sum = 0
+    else:
+        a = np.apply_along_axis(mutual_information, axis = 0, arr = data[:,prev_variables_index], vector_2=candidate_variable).sum()
+        b = np.apply_along_axis(conditional_mutual_information, axis = 0, arr = data[:,prev_variables_index], vector_2=candidate_variable, condition=target_variable).sum()
+        redundancy_sum = a - b
 
     return mutual_information(candidate_variable, target_variable) - 1/prev_variables_len*redundancy_sum
 
@@ -209,10 +210,11 @@ def cife(data, target_variable, prev_variables_index, candidate_variable_index,
 
     candidate_variable = data[:,candidate_variable_index]
     
-    redundancy_sum = 0
-    for var in prev_variables_index:
-        a = mutual_information(data[:,var], candidate_variable)
-        b = conditional_mutual_information(data[:,var], candidate_variable, target_variable)
-        redundancy_sum += a - b
+    if len(prev_variables_index) == 0:
+        redundancy_sum = 0
+    else:
+        a = np.apply_along_axis(mutual_information, axis = 0, arr = data[:,prev_variables_index], vector_2=candidate_variable).sum()
+        b = np.apply_along_axis(conditional_mutual_information, axis = 0, arr = data[:,prev_variables_index], vector_2=candidate_variable, condition=target_variable).sum()
+        redundancy_sum = a - b
         
     return mutual_information(candidate_variable, target_variable) - beta*redundancy_sum
\ No newline at end of file
